/*******************************************************
   SERIAL_ISR.C
   Interupt Service Routine zu SERIAL.C
 *******************************************************/

#include "LPC22xx.h"
#include "StdTypes.h"
#include "setup.h"
#include "serial.h"
#include "serial_ISR.h"


/* UART0: Interrupt.
 1. Der Int wird ausgelst, wenn THR leer wird, also
 durch die Flanke voll-->leer.
 wenn THR erstmal leer ist, dann gibt's keinen
 weiteren Int
 ABER: Das Int-Signal zum VIC mu gelscht werden.
 Entweder durch Beschrteiben von U0THR oder durch
 Lesen von U0IIR
 2. der Int kann auch per Software-Int aktiviert werden
 und mu dann in der Int-Routine dediziert rckgesetzt
 werden.
 */
#if defined (GCC)
void __attribute__ ((interrupt("IRQ"))) Uart0TxService (void)
#else
#pragma arm
void __irq Uart0TxService (void)
#endif
{
  volatile long IIR;
  int si, so;
  si = v24sin;
  so = v24sout;
  VICSoftIntClr = (1<<6);    /* evtl. Soft Int lschen */
  IIR = U0IIR;               /* Ident Register lesen   */
  if ((si!=so) &&            /* wenn es was zu senden gibt     */
      (U0LSR & (1<<5)))      /* und Tx ein Byte vertragen kann */
  {  U0THR = V24puffer[v24sout];        /* Zeichen senden      */
     v24sout = (so+1) & (v24bufsize-1); /* Index weiterstellen */
  }
  VICVectAddr = 0;           /* clear Interrupt             */
}

#if !defined (GCC)
#pragma thumb
#endif
